;; Generated package description from xr.el  -*- no-byte-compile: t -*-
(define-package "xr" "2.0" "Convert string regexp to rx notation" '((emacs "27.1")) :commit "9048d15a8de605ad1ee9eba889e4ec90944d8416" :authors '(("Mattias Engdegård" . "mattiase@acm.org")) :maintainer '("Mattias Engdegård" . "mattiase@acm.org") :keywords '("lisp" "regexps") :url "https://github.com/mattiase/xr")
